@@ -36,7 +36,6 @@ my $md5obj = new MD5;
 
 #Grab da OS name
 chomp($os_type=lc(qx[uname]));
-#open LOG, "|cat";
 
 &ParseConfigs;
 
@@ -62,9 +61,9 @@ if ($ARGV[0] eq '-init'){
 	print "Check Detected: Now Checking File Sanity...\n";
 	&Go;
 } else {
-	print "\n\nViperDB v0.9.7\n";
+	print "\n\nViperDB v0.9.8\n";
 	print "ERROR: Unrecognized option or none given.\n";
-	print "usage: ViperDB [-init|-check|-checkstrict] [-md5]\n";
+	print "usage: ViperDB -init|-check|-checkstrict [-md5]\n";
 	print "     -init	  Initializes the ViperDB Databases\n";
 	print "     -check	Runs a system file sanity check\n";
 	print "     -checkstrict   Runs a system file sanity check (protective)\n";
@@ -85,7 +84,7 @@ sub Lock
 		$pid = chomp $tmp;
 		close LOCK;
 		@tmp = `ps $pid|grep $pid`;
-		if (scalar @tmp == 1 && time () - $mtime < $timelock) {
+		if (scalar @tmp == 1 || time () - $mtime < $timelock) {
 			$locked = 1;
 		}
 	}
@@ -131,6 +130,7 @@ sub ParseConfigs
 				push @rignore, $_;
 			} elsif ($sub eq "dirs") {
 				$tmp = $_;
+				$opts = "";
 				if ($tmp =~ s/^([a-zA-Z0-9,]+)\s+//) {
 					$opts = $1;
 				}
